@@ -74,7 +74,9 @@ def init():
     apt_pkg.init()
     # force apt to build its caches in memory for now to make sure
     # that there is no race when the pkgcache file gets re-generated
+    #apt_pkg.config.set("debug::pkgcachegen","1")
     apt_pkg.config.set("Dir::Cache::pkgcache","")
+    apt_pkg.config.set("Dir::Cache::srcpkgcache","")
     
 def run(options=None):
 
