@@ -33,7 +33,8 @@ avahi_disabled_check(void)
         if (g_file_test (UNICAST_LOCAL_AVAHI_FILE, G_FILE_TEST_EXISTS)) {
                 /* Show the notification, after a delay so it doesn't look ugly
                  * if we've just logged in */
-                g_timeout_add(5000, (GSourceFunc)(show_notification), NULL);
+                g_timeout_add_seconds(5, (GSourceFunc)(show_notification),
+				      NULL);
         }
 
         return TRUE;
