@@ -111,9 +111,10 @@ distro_cd_detected(UpgradeNotifier *un,
       g_spawn_async (NULL, argv, NULL, 0, NULL, NULL, NULL, NULL);
       break;
    case RES_DIST_UPGRADER:
-      argv[0] = "/usr/lib/update-notifier/cddistupgrader";
-      argv[1] = (gchar *)mount_point;
-      argv[2] = NULL;
+      argv[0] = "/usr/bin/pkexec";
+      argv[1] = "/usr/lib/update-notifier/cddistupgrader";
+      argv[2] = (gchar *)mount_point;
+      argv[3] = NULL;
       g_spawn_async (NULL, argv, NULL, 0, NULL, NULL, NULL, NULL);
       break;
    default:
