@@ -192,7 +192,7 @@ crashreport_check (TrayApplet *ta)
       tray_applet_ui_set_visible(ta, TRUE);
       /* Show the notification, after a delay so it doesn't look ugly
        * if we've just logged in */
-      g_timeout_add(5000, (GSourceFunc)(show_notification), ta);
+      g_timeout_add_seconds(5, (GSourceFunc)(show_notification), ta);
    }
 
    // no crashreports, but visible
