@@ -785,7 +785,7 @@ gboolean check_update_hooks(TrayApplet *ta)
 
       // no dialog, do the notification
       if(!tray_applet_ui_get_visible (ta))
-	 g_timeout_add(5000, show_notification, ta);
+	 g_timeout_add_seconds(5, show_notification, ta);
 
       tray_applet_ui_ensure (ta);
       tray_applet_ui_set_single_action(ta, _("Information available"),
