@@ -262,7 +262,7 @@ do_reboot_check (TrayApplet *ta)
 
 	/* Show the notification, after a delay so it doesn't look ugly
 	 * if we've just logged in */
-	g_timeout_add(5000, (GSourceFunc)(show_notification), ta);
+	g_timeout_add_seconds(5, (GSourceFunc)(show_notification), ta);
 
 }
 
