@@ -10,13 +10,6 @@
 #include <gudev/gudev.h>
 #include <sys/utsname.h>
 
-/* search path for firmare; second and fourth element are dynamically constructed
- * in uevent_init(). */
-const gchar* firmware_search_path[] = {
-    "/lib/firmware", NULL,
-    "/lib/firmware/updates", NULL,
-    NULL };
-
 gchar *hplip_helper[] = { "/usr/bin/hp-plugin-ubuntu", NULL };
 
 static inline void
@@ -59,7 +52,7 @@ deal_with_hplip_firmware(GUdevDevice *device)
     }
 
     // check return codes, 2 & 5 indicate that it has the firmware already
-    if (WEXITSTATUS(ret) != 2 && WEXITSTATUS(ret) != 5) 
+    if (WEXITSTATUS(ret) != 2 && WEXITSTATUS(ret) != 5)
     {
        g_debug_uevent ("hp-mkuri indicates no firmware needed");
        return TRUE;
@@ -154,8 +147,6 @@ uevent_init(void)
 	g_warning("uname() failed, not monitoring firmware");
 	return;
     }
-    firmware_search_path[1] = g_strdup_printf("/lib/firmware/%s", u.release);
-    firmware_search_path[3] = g_strdup_printf("/lib/firmware/updates/%s", u.release);
 
     GUdevClient* gudev = g_udev_client_new (subsytems);
     g_signal_connect (gudev, "uevent", G_CALLBACK (on_uevent), NULL);
