@@ -53,12 +53,8 @@
 extern gboolean up_get_clipboard (void);
 gboolean update_timer_finished(gpointer data);
 
-// the time when we check for fam events
-#define TIMEOUT_FAM 1000*5 /* 5 sec */
-
-// the timeout (in msec) for apt-get update (changes in 
-// /var/lib/apt/lists{/partial})
-#define TIMEOUT_APT_GET_UPDATE 1000*30 /* 30 sec */
+// the time when we check for fam events, in seconds
+#define TIMEOUT_FAM 5
 
 // the timeout (in sec) when a further activity from dpkg/apt
 // causes the applet to "ungray"
@@ -423,7 +419,8 @@ monitor_init(UpgradeNotifier *un)
 	 g_warning("can not add '%s'", monitor_dirs[i]);
    }
 
-   g_timeout_add (TIMEOUT_FAM, (GSourceFunc)file_monitor_periodic_check, un);
+   g_timeout_add_seconds (TIMEOUT_FAM,
+			  (GSourceFunc)file_monitor_periodic_check, un);
 
 
    return TRUE;
