@@ -53,7 +53,7 @@
 // security update autolaunch minimal time (12h)
 #define AUTOLAUNCH_MINIMAL_SECURITY_INTERVAL 12*60*60
 
-// this is the age that we tolerate for updates (7 dayd)
+// this is the age that we tolerate for updates (7 days)
 #define OUTDATED_NAG_AGE 60*60*24*7
 
 // this is the time we wait when we found outdated information for 
@@ -73,14 +73,17 @@
 #define OUTDATED_NAG_WAIT 6
 #endif
 
-void invoke_with_gksu(const gchar *cmd, const gchar *descr, gboolean whole_message);
-void invoke(const gchar *cmd, const gchar *desktop, gboolean with_gksu);
-gboolean in_admin_group();
+void invoke_with_pkexec(const gchar *cmd);
+void invoke(const gchar *cmd, const gchar *desktop, gboolean with_pkexec);
+gboolean in_admin_group(void);
 
 typedef struct _TrayApplet TrayApplet;
+typedef struct _UpgradeNotifier UpgradeNotifier;
+
 struct _TrayApplet 
 {
    GObject me;
+   UpgradeNotifier *un;
 #ifdef HAVE_APP_INDICATOR
    AppIndicator *indicator;
 #else
@@ -91,9 +94,10 @@ struct _TrayApplet
    void *user_data;
 };
 
-typedef struct _UpgradeNotifier UpgradeNotifier;
 struct _UpgradeNotifier
 {
+   GSettings *settings;
+
    TrayApplet *update;
    TrayApplet *reboot;
    TrayApplet *hook;
@@ -105,7 +109,7 @@ struct _UpgradeNotifier
    // some states for the file montioring (these field
    // are the state for the current "time-slice")
    gboolean dpkg_was_run;
-   gboolean apt_get_runing;
+   gboolean apt_get_running;
 
    // these field are "global" (time-wise)
    gboolean reboot_pending;
