@@ -20,6 +20,7 @@
 #include "trayappletui.h"
 
 #define UPGRADE_CHECKER PACKAGE_LIB_DIR"/update-notifier/apt-check"
+#define PACKAGE_SYSTEM_LOCKED PACKAGE_LIB_DIR"/update-notifier/package-system-locked"
 
 // command, description, desktopfile, needs_pkexec
 const char* actions[][4] = {
@@ -295,56 +296,32 @@ outdated_nag(TrayApplet *ta)
    return FALSE;
 }
 
-// use ubuntu-system-service (if available) to check
+// use package-system-locked to check
 // if the dpkg lock is taken currently or not
 //
 // if uncertain, return FALSE 
 static gboolean
 dpkg_lock_is_taken (void)
 {
-  GError *error;
-  GVariant *answer;
-  GDBusProxy *proxy;
-  gboolean locked = FALSE;
-  
-  error = NULL;
-  proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
-                                         G_DBUS_PROXY_FLAGS_NONE,
-                                         NULL, /* GDBusInterfaceInfo */
-                                         "com.ubuntu.SystemService",
-                                         "/",
-                                         "com.ubuntu.SystemService",
-                                         NULL, /* GCancellable */
-                                         &error);
-  if (proxy == NULL) {
-    g_debug_update ("Failed to open connection to bus: %s", error->message);
-    g_error_free (error);
-    return FALSE;
-  }
+    gchar *cmd[] = { "pkexec", PACKAGE_SYSTEM_LOCKED, NULL };
+    gint exit_status;
+    GError *err = NULL;
 
-  error = NULL;
-  answer = g_dbus_proxy_call_sync (proxy, "is_package_system_locked", NULL,
-                                   G_DBUS_CALL_FLAGS_NONE, -1, NULL, &error);
-  g_object_unref (proxy);
+    if(!g_spawn_sync(NULL, cmd, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL,
+                NULL, NULL, NULL, NULL, &exit_status, &err)) {
+        g_warning("failed to run " PACKAGE_SYSTEM_LOCKED ": %s", err->message);
+        g_error_free(err);
+        return FALSE;
+    }
 
-  if (answer == NULL) {
-    g_debug_update ("error during dbus call: %s", error->message);
-    g_error_free (error);
-    return FALSE;
-  }
+    if(!WIFEXITED(exit_status)) {
+        g_warning(PACKAGE_SYSTEM_LOCKED " exited abnormally with code %i", exit_status);
+        return FALSE;
+    }
 
-  if (g_strcmp0 (g_variant_get_type_string (answer), "(b)") != 0) {
-    g_debug_update ("SystemService answer in unexpected format: %s",
-                    g_variant_get_type_string (answer));
-    g_variant_unref (answer);
-    return FALSE;
-  }
-
-  g_variant_get (answer, "(b)", &locked);
-  g_variant_unref (answer);
-
-  g_debug_update ("is_package_system_locked: %i", locked);
-  return locked;
+    exit_status = WEXITSTATUS(exit_status);
+    g_debug_update ("is_package_system_locked: " PACKAGE_SYSTEM_LOCKED "returned %i", exit_status);
+    return exit_status == 2;
 }
 
 #if 0
